@@ -1,10 +1,13 @@
 context("as_shadow_upset words")
 
-
+test_that("as_shadow_upset errors when given datasets with <= 1 variables", {
+  expect_error(as_shadow_upset(diag_na(1)))
+  expect_error(as_shadow_upset(data.frame(x = NA)))
+  expect_error(as_shadow_upset(data.frame(numeric(0))))
+})
 
 test_that("as_shadow_upset returns a data.frame",{
-  expect_s3_class(as_shadow_upset(airquality),
-                  "data.frame")
+  expect_s3_class(as_shadow_upset(airquality), "data.frame")
 })
 
 test_that("as_shadow_upset errors when given non dataframe or 0 entry",{
