@@ -25,14 +25,40 @@ test_that("miss_scan_count returns a data.frame of the right size", {
                 c(3,2))
 })
 
-correct_answer <- tibble::tribble(
+correct_answer_1 <- tibble::tribble(
   ~Variable, ~n,
   "x", 1L,
   "y", 0L,
   "z", 1L
 )
 
+correct_answer_2 <- tibble::tribble(
+  ~Variable, ~n,
+  "x", 2L,
+  "y", 0L,
+  "z", 2L
+)
+
+correct_answer_3 <- tibble::tribble(
+  ~Variable, ~n,
+  "x", 2L,
+  "y", 1L,
+  "z", 2L
+)
+
+correct_answer_4 <- tibble::tribble(
+  ~Variable, ~n,
+  "x", 2L,
+  "y", 1L,
+  "z", 2L
+)
+
 test_that("miss_scan_count returns the right answer", {
   expect_equal(miss_scan_count(dat_ms,-99),
-               correct_answer)
+               correct_answer_1)
+  expect_equal(miss_scan_count(dat_ms,c(-99,-98)),
+               correct_answer_2)
 })
+
+
+
